import { Subject } from 'rxjs';
import { EditViewBase } from '@/studio-core';
import EAMApplyService from '@/service/eamapply/eamapply-service';
import EAMApplyAuthService from '@/authservice/eamapply/eamapply-auth-service';
import EditViewEngine from '@engine/view/edit-view-engine';
import EAMApplyUIService from '@/uiservice/eamapply/eamapply-ui-service';

/**
 * 维护申请主信息视图基类
 *
 * @export
 * @class EAMApplyInfo_MainViewBase
 * @extends {EditViewBase}
 */
export class EAMApplyInfo_MainViewBase extends EditViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMApplyInfo_MainViewBase
     */
    protected appDeName: string = 'eamapply';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMApplyInfo_MainViewBase
     */
    protected appDeKey: string = 'eamapplyid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMApplyInfo_MainViewBase
     */
    protected appDeMajor: string = 'eamapplyname';

    /**
     * 实体服务对象
     *
     * @type {EAMApplyService}
     * @memberof EAMApplyInfo_MainViewBase
     */
    protected appEntityService: EAMApplyService = new EAMApplyService;

    /**
     * 实体权限服务对象
     *
     * @type EAMApplyUIService
     * @memberof EAMApplyInfo_MainViewBase
     */
    public appUIService: EAMApplyUIService = new EAMApplyUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMApplyInfo_MainViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMApplyInfo_MainViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamapply.views.info_mainview.caption',
        srfTitle: 'entities.eamapply.views.info_mainview.title',
        srfSubTitle: 'entities.eamapply.views.info_mainview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMApplyInfo_MainViewBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '0ef17d615938cdc829d919042267c23a';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMApplyInfo_MainViewBase
     */
    public engine: EditViewEngine = new EditViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMApplyInfo_MainViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'eamapply',
            majorPSDEField: 'eamapplyname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMApplyInfo_MainViewBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMApplyInfo_MainViewBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMApplyInfo_MainViewBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}