import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import EAMApplyService from '@/service/eamapply/eamapply-service';
import EAMApplyAuthService from '@/authservice/eamapply/eamapply-auth-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';
import EAMApplyUIService from '@/uiservice/eamapply/eamapply-ui-service';

/**
 * 维护申请信息视图基类
 *
 * @export
 * @class EAMApplyInfoViewBase
 * @extends {TabExpViewBase}
 */
export class EAMApplyInfoViewBase extends TabExpViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMApplyInfoViewBase
     */
    protected appDeName: string = 'eamapply';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMApplyInfoViewBase
     */
    protected appDeKey: string = 'eamapplyid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMApplyInfoViewBase
     */
    protected appDeMajor: string = 'eamapplyname';

    /**
     * 实体服务对象
     *
     * @type {EAMApplyService}
     * @memberof EAMApplyInfoViewBase
     */
    protected appEntityService: EAMApplyService = new EAMApplyService;

    /**
     * 实体权限服务对象
     *
     * @type EAMApplyUIService
     * @memberof EAMApplyInfoViewBase
     */
    public appUIService: EAMApplyUIService = new EAMApplyUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMApplyInfoViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMApplyInfoViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamapply.views.infoview.caption',
        srfTitle: 'entities.eamapply.views.infoview.title',
        srfSubTitle: 'entities.eamapply.views.infoview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMApplyInfoViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '96e58ee9a57415beb8209aae53b14926';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMApplyInfoViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMApplyInfoViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'eamapply',
            majorPSDEField: 'eamapplyname',
            isLoadDefault: true,
        });
    }


}