import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMServiceLevelService from '@/service/eamservice-level/eamservice-level-service';
import EAMServiceLevelAuthService from '@/authservice/eamservice-level/eamservice-level-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMServiceLevelUIService from '@/uiservice/eamservice-level/eamservice-level-ui-service';

/**
 * 服务等级数据选择视图视图基类
 *
 * @export
 * @class EAMServiceLevelPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMServiceLevelPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMServiceLevelPickupViewBase
     */
    protected appDeName: string = 'eamservicelevel';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMServiceLevelPickupViewBase
     */
    protected appDeKey: string = 'eamservicelevelid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMServiceLevelPickupViewBase
     */
    protected appDeMajor: string = 'eamservicelevelname';

    /**
     * 实体服务对象
     *
     * @type {EAMServiceLevelService}
     * @memberof EAMServiceLevelPickupViewBase
     */
    protected appEntityService: EAMServiceLevelService = new EAMServiceLevelService;

    /**
     * 实体权限服务对象
     *
     * @type EAMServiceLevelUIService
     * @memberof EAMServiceLevelPickupViewBase
     */
    public appUIService: EAMServiceLevelUIService = new EAMServiceLevelUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMServiceLevelPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMServiceLevelPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamservicelevel.views.pickupview.caption',
        srfTitle: 'entities.eamservicelevel.views.pickupview.title',
        srfSubTitle: 'entities.eamservicelevel.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMServiceLevelPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '688cebc536955dbea3a807bd19d98fcc';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMServiceLevelPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMServiceLevelPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamservicelevel',
            majorPSDEField: 'eamservicelevelname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMServiceLevelPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMServiceLevelPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMServiceLevelPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}