import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import EAMWorkOrderService from '@/service/eamwork-order/eamwork-order-service';
import EAMWorkOrderAuthService from '@/authservice/eamwork-order/eamwork-order-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import EAMWorkOrderUIService from '@/uiservice/eamwork-order/eamwork-order-ui-service';

/**
 * 工单选择表格视图视图基类
 *
 * @export
 * @class EAMWorkOrderPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class EAMWorkOrderPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected appDeName: string = 'eamworkorder';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected appDeKey: string = 'workorderid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected appDeMajor: string = 'workordername';

    /**
     * 实体服务对象
     *
     * @type {EAMWorkOrderService}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected appEntityService: EAMWorkOrderService = new EAMWorkOrderService;

    /**
     * 实体权限服务对象
     *
     * @type EAMWorkOrderUIService
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public appUIService: EAMWorkOrderUIService = new EAMWorkOrderUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMWorkOrderPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamworkorder.views.pickupgridview.caption',
        srfTitle: 'entities.eamworkorder.views.pickupgridview.title',
        srfSubTitle: 'entities.eamworkorder.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '99fce329ae1f308142b5b735a41769eb';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'eamworkorder',
            majorPSDEField: 'workordername',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof EAMWorkOrderPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}