import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import EAMWorkOrderService from '@/service/eamwork-order/eamwork-order-service';
import EAMWorkOrderAuthService from '@/authservice/eamwork-order/eamwork-order-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import EAMWorkOrderUIService from '@/uiservice/eamwork-order/eamwork-order-ui-service';

/**
 * 工单数据选择视图视图基类
 *
 * @export
 * @class EAMWorkOrderPickupViewBase
 * @extends {PickupViewBase}
 */
export class EAMWorkOrderPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderPickupViewBase
     */
    protected appDeName: string = 'eamworkorder';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderPickupViewBase
     */
    protected appDeKey: string = 'workorderid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderPickupViewBase
     */
    protected appDeMajor: string = 'workordername';

    /**
     * 实体服务对象
     *
     * @type {EAMWorkOrderService}
     * @memberof EAMWorkOrderPickupViewBase
     */
    protected appEntityService: EAMWorkOrderService = new EAMWorkOrderService;

    /**
     * 实体权限服务对象
     *
     * @type EAMWorkOrderUIService
     * @memberof EAMWorkOrderPickupViewBase
     */
    public appUIService: EAMWorkOrderUIService = new EAMWorkOrderUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMWorkOrderPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMWorkOrderPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamworkorder.views.pickupview.caption',
        srfTitle: 'entities.eamworkorder.views.pickupview.title',
        srfSubTitle: 'entities.eamworkorder.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMWorkOrderPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'e2c689498cfbde8c97c67a790b1831b8';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMWorkOrderPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMWorkOrderPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'eamworkorder',
            majorPSDEField: 'workordername',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMWorkOrderPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}