import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import WOOriginService from '@/service/woorigin/woorigin-service';
import WOOriginAuthService from '@/authservice/woorigin/woorigin-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import WOOriginUIService from '@/uiservice/woorigin/woorigin-ui-service';

/**
 * 工单来源选择表格视图视图基类
 *
 * @export
 * @class WOOriginPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class WOOriginPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof WOOriginPickupGridViewBase
     */
    protected appDeName: string = 'woorigin';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof WOOriginPickupGridViewBase
     */
    protected appDeKey: string = 'eamwooriginid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof WOOriginPickupGridViewBase
     */
    protected appDeMajor: string = 'eamwooriginname';

    /**
     * 实体服务对象
     *
     * @type {WOOriginService}
     * @memberof WOOriginPickupGridViewBase
     */
    protected appEntityService: WOOriginService = new WOOriginService;

    /**
     * 实体权限服务对象
     *
     * @type WOOriginUIService
     * @memberof WOOriginPickupGridViewBase
     */
    public appUIService: WOOriginUIService = new WOOriginUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof WOOriginPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof WOOriginPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.woorigin.views.pickupgridview.caption',
        srfTitle: 'entities.woorigin.views.pickupgridview.title',
        srfSubTitle: 'entities.woorigin.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof WOOriginPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '34cf27e1eddc36c197176c5632b97179';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof WOOriginPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof WOOriginPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'woorigin',
            majorPSDEField: 'wooriginname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof WOOriginPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}