import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import WOOriginService from '@/service/woorigin/woorigin-service';
import WOOriginAuthService from '@/authservice/woorigin/woorigin-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import WOOriginUIService from '@/uiservice/woorigin/woorigin-ui-service';

/**
 * 工单来源数据选择视图视图基类
 *
 * @export
 * @class WOOriginPickupViewBase
 * @extends {PickupViewBase}
 */
export class WOOriginPickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof WOOriginPickupViewBase
     */
    protected appDeName: string = 'woorigin';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof WOOriginPickupViewBase
     */
    protected appDeKey: string = 'eamwooriginid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof WOOriginPickupViewBase
     */
    protected appDeMajor: string = 'eamwooriginname';

    /**
     * 实体服务对象
     *
     * @type {WOOriginService}
     * @memberof WOOriginPickupViewBase
     */
    protected appEntityService: WOOriginService = new WOOriginService;

    /**
     * 实体权限服务对象
     *
     * @type WOOriginUIService
     * @memberof WOOriginPickupViewBase
     */
    public appUIService: WOOriginUIService = new WOOriginUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof WOOriginPickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof WOOriginPickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.woorigin.views.pickupview.caption',
        srfTitle: 'entities.woorigin.views.pickupview.title',
        srfSubTitle: 'entities.woorigin.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof WOOriginPickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '06ee1c500b1cb4aa576fb3b62b4ddb35';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof WOOriginPickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof WOOriginPickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'woorigin',
            majorPSDEField: 'wooriginname',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof WOOriginPickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}